@@ -1,6 +1,6 @@
 package App::setop;
 
-our $VERSION = '0.09'; # VERSION
+our $VERSION = '0.10'; # VERSION
 
 1;
 # ABSTRACT: Set operations (union, intersection, difference, symmetric diff) on lines of files
@@ -17,19 +17,25 @@ App::setop - Set operations (union, intersection, difference, symmetric diff) on
 
 =head1 VERSION
 
-This document describes version 0.09 of App::setop (from Perl distribution App-setop), released on 2015-01-17.
+This document describes version 0.10 of App::setop (from Perl distribution App-setop), released on 2015-11-13.
 
 =head1 SYNOPSIS
 
 See the command-line script L<setop>.
 
+=head1 SEE ALSO
+
+L<Array::Utils>
+
+L<Set::Scalar>
+
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/App-setop>.
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-App-setop>.
+Source repository is at L<https://github.com/perlancar/perl-App-setop>.
 
 =head1 BUGS
 
